@@ -24,8 +24,8 @@
 #include <log4cxx/helpers/loglog.h>
 #include <log4cxx/helpers/transcoder.h>
 
-#ifdef WIN32
-#include <Windows.h>
+#ifdef _WIN32
+#include <windows.h>
 #elif __APPLE__
 #include <mach-o/dyld.h>
 #elif (defined(_XOPEN_SOURCE) && _XOPEN_SOURCE >= 500) || (defined(_POSIX_C_SOURCE) && _POSIX_C_SOURCE >= 200112L)
@@ -48,7 +48,7 @@ auto DefaultConfigurationFileNames(std::string& altPrefix) -> std::vector<std::s
 	static const int bufSize = 4096;
 	char buf[bufSize+1] = {0}, pathSepar = '/';
 	uint32_t bufCount = 0;
-#if defined(WIN32)
+#if defined(_WIN32)
 	GetModuleFileName(NULL, buf, bufSize);
 	pathSepar = '\\';
 #elif defined(__APPLE__)
@@ -67,31 +67,35 @@ auto DefaultConfigurationFileNames(std::string& altPrefix) -> std::vector<std::s
 	if (std::string::npos != slashIndex) {
 		// Extract the path
 		altPrefix = programFileName.substr(0, slashIndex + 1);
-#if defined(_DEBUG)
-		LogString msg1 = LOG4CXX_STR("Alternate prefix [");
-		helpers::Transcoder::decode(altPrefix, msg1);
-		msg1 += LOG4CXX_STR("]");
-		helpers::LogLog::debug(msg1);
-#endif
+		if (helpers::LogLog::isDebugEnabled())
+		{
+			LogString msg = LOG4CXX_STR("Alternate prefix [");
+			helpers::Transcoder::decode(altPrefix, msg);
+			msg += LOG4CXX_STR("]");
+			helpers::LogLog::debug(msg);
+		}
 		// Add a local directory relative name
 		result.push_back(programFileName.substr(slashIndex + 1));
-#if defined(_DEBUG)
-		LogString msg2(LOG4CXX_STR("Alternate configuration file name ["));
-		helpers::Transcoder::decode(result.back(), msg2);
-		msg2 += LOG4CXX_STR("]");
-		helpers::LogLog::debug(msg2);
-#endif
+		if (helpers::LogLog::isDebugEnabled())
+		{
+			LogString msg(LOG4CXX_STR("Alternate configuration file name ["));
+			helpers::Transcoder::decode(result.back(), msg);
+			msg += LOG4CXX_STR("]");
+			helpers::LogLog::debug(msg);
+		}
 		// Add a local directory relative name without any extension
 		auto dotIndex = result.back().rfind('.');
-		if (std::string::npos != dotIndex) {
+		if (std::string::npos != dotIndex)
+		{
 			result.push_back(result.back());
 			result.back().erase(dotIndex);
-#if defined(_DEBUG)
-			LogString msg3(LOG4CXX_STR("Alternate configuration file name ["));
-			helpers::Transcoder::decode(result.back(), msg3);
-			msg3 += LOG4CXX_STR("]");
-			helpers::LogLog::debug(msg3);
-#endif
+			if (helpers::LogLog::isDebugEnabled())
+			{
+				LogString msg(LOG4CXX_STR("Alternate configuration file name ["));
+				helpers::Transcoder::decode(result.back(), msg);
+				msg += LOG4CXX_STR("]");
+				helpers::LogLog::debug(msg);
+			}
 		}
 	}
 	else if (!programFileName.empty()) {
@@ -99,12 +103,13 @@ auto DefaultConfigurationFileNames(std::string& altPrefix) -> std::vector<std::s
 		if (std::string::npos != dotIndex) {
 			programFileName.erase(dotIndex);
 			result.push_back(programFileName);
-#if defined(_DEBUG)
-			LogString msg(LOG4CXX_STR("Alternate configuration file name ["));
-			helpers::Transcoder::decode(result.back(), msg);
-			msg += LOG4CXX_STR("]");
-			helpers::LogLog::debug(msg);
-#endif
+			if (helpers::LogLog::isDebugEnabled())
+			{
+				LogString msg(LOG4CXX_STR("Alternate configuration file name ["));
+				helpers::Transcoder::decode(result.back(), msg);
+				msg += LOG4CXX_STR("]");
+				helpers::LogLog::debug(msg);
+			}
 		}
 	}
 	result.push_back("log4cxx");
