@@ -21,8 +21,8 @@
 #include <log4cxx/helpers/bytebuffer.h>
 #include <string.h>
 
-using namespace log4cxx;
-using namespace log4cxx::helpers;
+using namespace LOG4CXX_NS;
+using namespace LOG4CXX_NS::helpers;
 
 struct ByteArrayOutputStream::ByteArrayOutputStreamPriv
 {
