@@ -49,6 +49,7 @@
 #include <log4cxx/net/smtpappender.h>
 #include <log4cxx/helpers/messagebuffer.h>
 #include <log4cxx/helpers/threadutility.h>
+#include <log4cxx/helpers/singletonholder.h>
 
 #define LOG4CXX 1
 #include <log4cxx/helpers/aprinitializer.h>
@@ -89,11 +90,22 @@ class XMLWatchdog  : public FileWatchdog
 			DOMConfigurator().doConfigure(file(),
 				LogManager::getLoggerRepository());
 		}
+
+		static void startWatching(const File& filename, long delay)
+		{
+			using WatchdogHolder = SingletonHolder<XMLWatchdog>;
+			auto pHolder = APRInitializer::getOrAddUnique<WatchdogHolder>
+				( [&filename]() -> ObjectPtr
+					{ return std::make_shared<WatchdogHolder>(filename); }
+				);
+			auto& xdog = pHolder->value();
+			xdog.setFile(filename);
+			xdog.setDelay(0 < delay ? delay : FileWatchdog::DEFAULT_DELAY);
+			xdog.start();
+		}
 };
 }
 }
-XMLWatchdog* DOMConfigurator::xdog = NULL;
-
 
 IMPLEMENT_LOG4CXX_OBJECT(DOMConfigurator)
 
@@ -535,10 +547,6 @@ void DOMConfigurator::parseChildrenOfLoggerElement(
 	PropertySetter propSetter(logger);
 	std::vector<AppenderPtr> newappenders;
 
-	// Remove all existing appenders from logger. They will be
-	// reconstructed if need be.
-	logger->removeAllAppenders();
-
 	for (apr_xml_elem* currentElement = loggerElement->first_child;
 		currentElement;
 		currentElement = currentElement->next)
@@ -550,12 +558,12 @@ void DOMConfigurator::parseChildrenOfLoggerElement(
 			AppenderPtr appender = findAppenderByReference(p, utf8Decoder, currentElement, doc, appenders);
 			LogString refName =  subst(getAttribute(utf8Decoder, currentElement, REF_ATTR));
 
-			if (!LogLog::isDebugEnabled())
-				;
-			else if (appender != 0)
+			if (appender)
 			{
-				LogLog::debug(LOG4CXX_STR("Adding appender named [") + refName +
-					LOG4CXX_STR("] to logger [") + logger->getName() + LOG4CXX_STR("]."));
+				if (LogLog::isDebugEnabled())
+					LogLog::debug(LOG4CXX_STR("Adding appender named [") + refName +
+						LOG4CXX_STR("] to logger [") + logger->getName() + LOG4CXX_STR("]."));
+				newappenders.push_back(appender);
 			}
 			else
 			{
@@ -563,8 +571,6 @@ void DOMConfigurator::parseChildrenOfLoggerElement(
 					LOG4CXX_STR("] not found."));
 			}
 
-			logger->addAppender(appender);
-
 		}
 		else if (tagName == LEVEL_TAG)
 		{
@@ -579,6 +585,10 @@ void DOMConfigurator::parseChildrenOfLoggerElement(
 			setParameter(p, utf8Decoder, currentElement, propSetter);
 		}
 	}
+	if (newappenders.empty())
+		logger->removeAllAppenders();
+	else
+		logger->replaceAppenders(newappenders);
 
 	propSetter.activate(p);
 }
@@ -980,19 +990,8 @@ spi::ConfigurationStatus DOMConfigurator::configureAndWatch(const std::string& f
 
 spi::ConfigurationStatus DOMConfigurator::configureAndWatch(const File& file, long delay)
 {
-	if ( xdog )
-	{
-		APRInitializer::unregisterCleanup(xdog);
-		delete xdog;
-	}
-
 	spi::ConfigurationStatus status = DOMConfigurator().doConfigure(file, LogManager::getLoggerRepository());
-
-	xdog = new XMLWatchdog(file);
-	APRInitializer::registerCleanup(xdog);
-	xdog->setDelay(0 < delay ? delay : FileWatchdog::DEFAULT_DELAY);
-	xdog->start();
-
+	XMLWatchdog::startWatching(file, delay);
 	return status;
 }
 
@@ -1001,19 +1000,8 @@ spi::ConfigurationStatus DOMConfigurator::configureAndWatch(const File& file, lo
 spi::ConfigurationStatus DOMConfigurator::configureAndWatch(const std::wstring& filename, long delay)
 {
 	File file(filename);
-	if ( xdog )
-	{
-		APRInitializer::unregisterCleanup(xdog);
-		delete xdog;
-	}
-
 	spi::ConfigurationStatus status = DOMConfigurator().doConfigure(file, LogManager::getLoggerRepository());
-
-	xdog = new XMLWatchdog(file);
-	APRInitializer::registerCleanup(xdog);
-	xdog->setDelay(delay);
-	xdog->start();
-
+	XMLWatchdog::startWatching(file, delay);
 	return status;
 }
 #endif
@@ -1022,19 +1010,8 @@ spi::ConfigurationStatus DOMConfigurator::configureAndWatch(const std::wstring&
 spi::ConfigurationStatus DOMConfigurator::configureAndWatch(const std::basic_string<UniChar>& filename, long delay)
 {
 	File file(filename);
-	if ( xdog )
-	{
-		APRInitializer::unregisterCleanup(xdog);
-		delete xdog;
-	}
-
 	spi::ConfigurationStatus status = DOMConfigurator().doConfigure(file, LogManager::getLoggerRepository());
-
-	xdog = new XMLWatchdog(file);
-	APRInitializer::registerCleanup(xdog);
-	xdog->setDelay(delay);
-	xdog->start();
-
+	XMLWatchdog::startWatching(file, delay);
 	return status;
 }
 #endif
@@ -1043,19 +1020,8 @@ spi::ConfigurationStatus DOMConfigurator::configureAndWatch(const std::basic_str
 spi::ConfigurationStatus DOMConfigurator::configureAndWatch(const CFStringRef& filename, long delay)
 {
 	File file(filename);
-	if ( xdog )
-	{
-		APRInitializer::unregisterCleanup(xdog);
-		delete xdog;
-	}
-
 	spi::ConfigurationStatus status = DOMConfigurator().doConfigure(file, LogManager::getLoggerRepository());
-
-	xdog = new XMLWatchdog(file);
-	APRInitializer::registerCleanup(xdog);
-	xdog->setDelay(delay);
-	xdog->start();
-
+	XMLWatchdog::startWatching(file, delay);
 	return status;
 }
 #endif
