@@ -24,8 +24,8 @@
 #include <assert.h>
 #include <log4cxx/helpers/exception.h>
 
-using namespace log4cxx;
-using namespace log4cxx::helpers;
+using namespace LOG4CXX_NS;
+using namespace LOG4CXX_NS::helpers;
 
 struct File::FilePrivate{
 	FilePrivate() :
@@ -95,7 +95,7 @@ File::File(const wchar_t* name1)
 }
 #endif
 
-#if LOG4CXX_UNICHAR_API
+#if LOG4CXX_UNICHAR_API || LOG4CXX_LOGCHAR_IS_UNICHAR
 File::File(const std::basic_string<UniChar>& name1)
 	: m_priv(std::make_unique<FilePrivate>(decodeLS(name1)))
 {
