@@ -14,26 +14,26 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-#if defined(_MSC_VER)
-#pragma warning ( disable: 4231 4251 4275 4786 )
-#endif
 
 #include <log4cxx/logstring.h>
 #include <log4cxx/pattern/filedatepatternconverter.h>
 #include <log4cxx/pattern/datepatternconverter.h>
 
-using namespace log4cxx;
-using namespace log4cxx::pattern;
-using namespace log4cxx::spi;
-using namespace log4cxx::helpers;
+using namespace LOG4CXX_NS;
+using namespace LOG4CXX_NS::pattern;
+using namespace LOG4CXX_NS::spi;
+using namespace LOG4CXX_NS::helpers;
 
 PatternConverterPtr FileDatePatternConverter::newInstance(
-   const std::vector<LogString>& options) {
-   if (options.size() == 0) {
-     std::vector<LogString> altOptions;
-     altOptions.push_back(LOG4CXX_STR("yyyy-MM-dd"));
-     return DatePatternConverter::newInstance(altOptions);
-   }
-   return DatePatternConverter::newInstance(options);
+	const std::vector<LogString>& options)
+{
+	if (options.size() == 0)
+	{
+		std::vector<LogString> altOptions;
+		altOptions.push_back(LOG4CXX_STR("yyyy-MM-dd"));
+		return DatePatternConverter::newInstance(altOptions);
+	}
+
+	return DatePatternConverter::newInstance(options);
 }
 
