@@ -18,8 +18,8 @@
 #include <log4cxx/logstring.h>
 #include <log4cxx/helpers/integer.h>
 
-using namespace log4cxx;
-using namespace log4cxx::helpers;
+using namespace LOG4CXX_NS;
+using namespace LOG4CXX_NS::helpers;
 
 IMPLEMENT_LOG4CXX_OBJECT(Integer)
 
