@@ -38,12 +38,8 @@ using namespace LOG4CXX_NS::helpers;
 
 struct LoggingEvent::LoggingEventPrivate
 {
-	LoggingEventPrivate(const ThreadSpecificData::NamePairPtr& p = ThreadSpecificData::getNames()) :
+	LoggingEventPrivate(const ThreadSpecificData::NamePairPtr p = ThreadSpecificData::getNames()) :
 		timeStamp(0),
-#if LOG4CXX_ABI_VERSION <= 15
-		threadName(p->idString),
-		threadUserName(p->threadName),
-#endif
 		pNames(p)
 	{
 	}
@@ -53,17 +49,13 @@ struct LoggingEvent::LoggingEventPrivate
 		, const LevelPtr& level1
 		, const LocationInfo& locationInfo1
 		, LogString&& message1
-		, const ThreadSpecificData::NamePairPtr& p = ThreadSpecificData::getNames()
+		, const ThreadSpecificData::NamePairPtr p = ThreadSpecificData::getNames()
 		) :
 		logger(logger1),
 		level(level1),
 		message(std::move(message1)),
 		timeStamp(Date::currentTime()),
 		locationInfo(locationInfo1),
-#if LOG4CXX_ABI_VERSION <= 15
-		threadName(p->idString),
-		threadUserName(p->threadName),
-#endif
 		chronoTimeStamp(std::chrono::microseconds(timeStamp)),
 		pNames(p)
 	{
@@ -79,10 +71,6 @@ struct LoggingEvent::LoggingEventPrivate
 		message(message1),
 		timeStamp(Date::currentTime()),
 		locationInfo(locationInfo1),
-#if LOG4CXX_ABI_VERSION <= 15
-		threadName(p->idString),
-		threadUserName(p->threadName),
-#endif
 		chronoTimeStamp(std::chrono::microseconds(timeStamp)),
 		pNames(p)
 	{
@@ -101,23 +89,11 @@ struct LoggingEvent::LoggingEventPrivate
 	/** severity level of logging event. */
 	LevelPtr level;
 
-#if LOG4CXX_ABI_VERSION <= 15
-	mutable LogString* ndc{NULL};
-
-	mutable MDC::Map* mdcCopy{NULL};
-#endif
-
 	/**
 	* A map of String keys and String values.
 	*/
 	std::map<LogString, LogString>* properties{NULL};
 
-#if LOG4CXX_ABI_VERSION <= 15
-	mutable bool ndcLookupRequired{false};
-
-	mutable bool mdcCopyLookupRequired{false};
-#endif
-
 	/** The application supplied message. */
 	LogString message;
 
@@ -130,13 +106,6 @@ struct LoggingEvent::LoggingEventPrivate
 	/** The source code location where the logging request was made. */
 	const spi::LocationInfo locationInfo;
 
-
-#if LOG4CXX_ABI_VERSION <= 15
-	const LogString& threadName;
-
-	const LogString& threadUserName;
-#endif
-
 	std::chrono::time_point<std::chrono::system_clock> chronoTimeStamp;
 
 	/**
@@ -206,7 +175,7 @@ bool LoggingEvent::getNDC(LogString& dest) const
 	// Otherwise use the NDC that is associated with the thread.
 	if (m_priv->dc)
 	{
-		result = m_priv->dc->ctx.has_value();
+		result = bool(m_priv->dc->ctx);
 		if (result)
 			dest.append(NDC::getFullMessage(m_priv->dc->ctx.value()));
 	}
@@ -243,19 +212,24 @@ LoggingEvent::KeySet LoggingEvent::getMDCKeySet() const
 		for (auto const& item : m_priv->dc->map)
 			result.push_back(item.first);
 	}
-	else for (auto const& item : ThreadSpecificData::getCurrentData()->getMap())
-		result.push_back(item.first);
+	else if (auto pData = ThreadSpecificData::getCurrentData())
+	{
+		for (auto const& item : pData->getMap())
+			result.push_back(item.first);
+	}
 	return result;
 }
 
 void LoggingEvent::LoadDC() const
 {
 	m_priv->dc = std::make_unique<LoggingEventPrivate::DiagnosticContext>();
-	auto pData = ThreadSpecificData::getCurrentData();
-	m_priv->dc->map = pData->getMap();
-	auto& stack = pData->getStack();
-	if (!stack.empty())
-		m_priv->dc->ctx = stack.top();
+	if (auto pData = ThreadSpecificData::getCurrentData())
+	{
+		m_priv->dc->map = pData->getMap();
+		auto& stack = pData->getStack();
+		if (!stack.empty())
+			m_priv->dc->ctx = stack.top();
+	}
 }
 
 #if LOG4CXX_ABI_VERSION <= 15
