@@ -18,12 +18,14 @@
 #include <log4cxx/pattern/nameabbreviator.h>
 #include <log4cxx/helpers/exception.h>
 #include <log4cxx/helpers/stringhelper.h>
+#include <log4cxx/helpers/loglog.h>
 #include <vector>
 #include <limits.h>
+#include <stdexcept>
 
-using namespace log4cxx;
-using namespace log4cxx::pattern;
-using namespace log4cxx::helpers;
+using namespace LOG4CXX_NS;
+using namespace LOG4CXX_NS::pattern;
+using namespace LOG4CXX_NS::helpers;
 
 IMPLEMENT_LOG4CXX_OBJECT(NameAbbreviator)
 
@@ -35,7 +37,7 @@ NameAbbreviator::~NameAbbreviator()
 {
 }
 
-namespace log4cxx
+namespace LOG4CXX_NS
 {
 namespace pattern
 {
@@ -61,7 +63,7 @@ class NOPAbbreviator : public NameAbbreviator
 		/**
 		 * {@inheritDoc}
 		 */
-		void abbreviate(LogString::size_type /* nameStart */, LogString& /* buf */) const
+		void abbreviate(LogString::size_type /* nameStart */, LogString& /* buf */) const override
 		{
 		}
 };
@@ -96,7 +98,7 @@ class MaxElementAbbreviator : public NameAbbreviator
 		 * @param buf buffer to append abbreviation.
 		 * @param nameStart start of name to abbreviate.
 		 */
-		void abbreviate(LogString::size_type nameStart, LogString& buf) const
+		void abbreviate(LogString::size_type nameStart, LogString& buf) const override
 		{
 			// We substract 1 from 'len' when assigning to 'end' to avoid out of
 			// bounds exception in return r.substring(end+1, len). This can happen if
@@ -230,7 +232,7 @@ class PatternAbbreviator : public NameAbbreviator
 		 * @param buf buffer that abbreviated name is appended.
 		 * @param nameStart start of name.
 		 */
-		void abbreviate(LogString::size_type nameStart, LogString& buf) const
+		void abbreviate(LogString::size_type nameStart, LogString& buf) const override
 		{
 			//
 			//  all non-terminal patterns are executed once
@@ -291,7 +293,23 @@ NameAbbreviatorPtr NameAbbreviator::getAbbreviator(const LogString& pattern)
 		//
 		if (i == trimmed.length())
 		{
-			return NameAbbreviatorPtr(new MaxElementAbbreviator(StringHelper::toInt(trimmed)));
+			int len = 256;
+			try
+			{
+				len = StringHelper::toInt(trimmed);
+			}
+			catch (const std::out_of_range& ex)
+			{
+				LogLog::warn(LOG4CXX_STR("Invalid name abreviator pattern: ") + pattern, ex);
+			}
+
+			if(len > 256){
+				len = 256;
+			}else if( len < 0 ){
+				len = 0;
+			}
+
+			return std::make_shared<MaxElementAbbreviator>(len);
 		}
 
 		std::vector<PatternAbbreviatorFragment> fragments;
@@ -345,8 +363,7 @@ NameAbbreviatorPtr NameAbbreviator::getAbbreviator(const LogString& pattern)
 			pos++;
 		}
 
-		NameAbbreviatorPtr abbrev(new PatternAbbreviator(fragments));
-		return abbrev;
+		return std::make_shared<PatternAbbreviator>(fragments);
 	}
 
 	//
@@ -362,7 +379,7 @@ NameAbbreviatorPtr NameAbbreviator::getAbbreviator(const LogString& pattern)
  */
 NameAbbreviatorPtr NameAbbreviator::getDefaultAbbreviator()
 {
-	static NameAbbreviatorPtr def(new NOPAbbreviator());
+	static WideLife<NameAbbreviatorPtr> def = std::make_shared<NOPAbbreviator>();
 	return def;
 }
 
