@@ -14,10 +14,6 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-#if defined(_MSC_VER)
-	#pragma warning ( disable: 4231 4251 4275 4786 )
-#endif
-
 
 #include <log4cxx/logstring.h>
 #include <log4cxx/rolling/rollingpolicybase.h>
@@ -29,26 +25,31 @@
 #include <log4cxx/pattern/integerpatternconverter.h>
 #include <log4cxx/pattern/datepatternconverter.h>
 #include <log4cxx/helpers/optionconverter.h>
+#include <log4cxx/private/rollingpolicybase_priv.h>
 
-using namespace log4cxx;
-using namespace log4cxx::rolling;
-using namespace log4cxx::helpers;
-using namespace log4cxx::pattern;
+using namespace LOG4CXX_NS;
+using namespace LOG4CXX_NS::rolling;
+using namespace LOG4CXX_NS::helpers;
+using namespace LOG4CXX_NS::pattern;
 
 IMPLEMENT_LOG4CXX_OBJECT(RollingPolicyBase)
 
-RollingPolicyBase::RollingPolicyBase()
+RollingPolicyBase::RollingPolicyBase() :
+	m_priv(std::make_unique<RollingPolicyBasePrivate>())
 {
-	createIntermediateDirectories = true;
+}
+
+RollingPolicyBase::RollingPolicyBase( std::unique_ptr<RollingPolicyBasePrivate> priv ) :
+	m_priv(std::move(priv)){
 }
 
 RollingPolicyBase::~RollingPolicyBase()
 {
 }
 
-void RollingPolicyBase::activateOptions(log4cxx::helpers::Pool& /* pool */)
+void RollingPolicyBase::activateOptions(LOG4CXX_NS::helpers::Pool& /* pool */)
 {
-	if (fileNamePatternStr.length() > 0)
+	if (m_priv->fileNamePatternStr.length() > 0)
 	{
 		parseFileNamePattern();
 	}
@@ -69,24 +70,24 @@ void RollingPolicyBase::setOption(const LogString& option, const LogString& valu
 			LOG4CXX_STR("FILENAMEPATTERN"),
 			LOG4CXX_STR("filenamepattern")))
 	{
-		fileNamePatternStr = value;
+		m_priv->fileNamePatternStr = value;
 	}else if (StringHelper::equalsIgnoreCase(option,
 			LOG4CXX_STR("CREATEINTERMEDIATEDIRECTORIES"),
 			LOG4CXX_STR("createintermediatedirectories")))
 	{
-		createIntermediateDirectories = OptionConverter::toBoolean(value, false);
+		m_priv->createIntermediateDirectories = OptionConverter::toBoolean(value, false);
 	}
 }
 
 void RollingPolicyBase::setFileNamePattern(const LogString& fnp)
 {
-	fileNamePatternStr = fnp;
+	m_priv->fileNamePatternStr = fnp;
 }
 
 
 LogString RollingPolicyBase::getFileNamePattern() const
 {
-	return fileNamePatternStr;
+	return m_priv->fileNamePatternStr;
 }
 
 /**
@@ -94,11 +95,11 @@ LogString RollingPolicyBase::getFileNamePattern() const
  */
 void RollingPolicyBase::parseFileNamePattern()
 {
-	patternConverters.erase(patternConverters.begin(), patternConverters.end());
-	patternFields.erase(patternFields.begin(), patternFields.end());
-	PatternParser::parse(fileNamePatternStr,
-		patternConverters,
-		patternFields,
+	m_priv->patternConverters.erase(m_priv->patternConverters.begin(), m_priv->patternConverters.end());
+	m_priv->patternFields.erase(m_priv->patternFields.begin(), m_priv->patternFields.end());
+	PatternParser::parse(m_priv->fileNamePatternStr,
+		m_priv->patternConverters,
+		m_priv->patternFields,
 		getFormatSpecifiers());
 }
 
@@ -109,21 +110,21 @@ void RollingPolicyBase::parseFileNamePattern()
  * @param buf string buffer to which formatted file name is appended, may not be null.
  */
 void RollingPolicyBase::formatFileName(
-	ObjectPtr& obj,
+	const ObjectPtr& obj,
 	LogString& toAppendTo,
 	Pool& pool) const
 {
 	std::vector<FormattingInfoPtr>::const_iterator formatterIter =
-		patternFields.begin();
+		m_priv->patternFields.begin();
 
 	for (std::vector<PatternConverterPtr>::const_iterator
-		converterIter = patternConverters.begin();
-		converterIter != patternConverters.end();
+		converterIter = m_priv->patternConverters.begin();
+		converterIter != m_priv->patternConverters.end();
 		converterIter++, formatterIter++)
 	{
-		int startField = toAppendTo.length();
+		auto startField = toAppendTo.length();
 		(*converterIter)->format(obj, toAppendTo, pool);
-		(*formatterIter)->format(startField, toAppendTo);
+		(*formatterIter)->format((int)startField, toAppendTo);
 	}
 }
 
@@ -131,13 +132,13 @@ void RollingPolicyBase::formatFileName(
 PatternConverterPtr RollingPolicyBase::getIntegerPatternConverter() const
 {
 	for (std::vector<PatternConverterPtr>::const_iterator
-		converterIter = patternConverters.begin();
-		converterIter != patternConverters.end();
+		converterIter = m_priv->patternConverters.begin();
+		converterIter != m_priv->patternConverters.end();
 		converterIter++)
 	{
 		IntegerPatternConverterPtr intPattern;
 		PatternConverterPtr patternptr = (*converterIter);
-		intPattern = log4cxx::cast<IntegerPatternConverter>(patternptr);
+		intPattern = LOG4CXX_NS::cast<IntegerPatternConverter>(patternptr);
 
 		if (intPattern != NULL)
 		{
@@ -152,13 +153,13 @@ PatternConverterPtr RollingPolicyBase::getIntegerPatternConverter() const
 PatternConverterPtr RollingPolicyBase::getDatePatternConverter() const
 {
 	for (std::vector<PatternConverterPtr>::const_iterator
-		converterIter = patternConverters.begin();
-		converterIter != patternConverters.end();
+		converterIter = m_priv->patternConverters.begin();
+		converterIter != m_priv->patternConverters.end();
 		converterIter++)
 	{
 		DatePatternConverterPtr datePattern;
 		PatternConverterPtr patternptr = (*converterIter);
-		datePattern = log4cxx::cast<DatePatternConverter>(patternptr);
+		datePattern = LOG4CXX_NS::cast<DatePatternConverter>(patternptr);
 
 		if (datePattern != NULL)
 		{
@@ -171,11 +172,14 @@ PatternConverterPtr RollingPolicyBase::getDatePatternConverter() const
 }
 
 bool RollingPolicyBase::getCreateIntermediateDirectories() const{
-	return createIntermediateDirectories;
+	return m_priv->createIntermediateDirectories;
 }
 
 void RollingPolicyBase::setCreateIntermediateDirectories(bool createIntermediate){
-	createIntermediateDirectories = createIntermediate;
+	m_priv->createIntermediateDirectories = createIntermediate;
 }
 
-
+PatternConverterList RollingPolicyBase::getPatternConverterList() const
+{
+	return m_priv->patternConverters;
+}
