@@ -20,19 +20,26 @@
 #include <log4cxx/level.h>
 #include <log4cxx/appender.h>
 
-using namespace log4cxx;
-using namespace log4cxx::spi;
-using namespace log4cxx::helpers;
+using namespace LOG4CXX_NS;
+using namespace LOG4CXX_NS::spi;
+using namespace LOG4CXX_NS::helpers;
 
-RootLogger::RootLogger(Pool& pool, const LevelPtr level1) :
-	Logger(pool, LOG4CXX_STR("root"))
+RootLogger::RootLogger(const LevelPtr& level1)
+	: Logger(LOG4CXX_STR("root"))
 {
 	setLevel(level1);
 }
 
+#if LOG4CXX_ABI_VERSION <= 15
+RootLogger::RootLogger(Pool&, const LevelPtr level)
+	: RootLogger(level)
+{
+}
+#endif
+
 const LevelPtr& RootLogger::getEffectiveLevel() const
 {
-	return level;
+	return getLevel();
 }
 
 void RootLogger::setLevel(const LevelPtr level1)
@@ -43,8 +50,7 @@ void RootLogger::setLevel(const LevelPtr level1)
 	}
 	else
 	{
-
-		this->level = level1;
+		Logger::setLevel(level1);
 	}
 }
 
