@@ -52,9 +52,14 @@ struct TelnetAppender::TelnetAppenderPriv : public AppenderSkeletonPrivate
 #if LOG4CXX_EVENTS_AT_EXIT
 		, atExitRegistryRaii([this]{stopAcceptingConnections();})
 #endif
-        { stopAcceptingConnections(); }
+	{ }
+
+	~TelnetAppenderPriv()
+	{ stopAcceptingConnections(); }
 
 	int port;
+	LogString hostname;
+	bool reuseAddress = false;
 	ConnectionList connections;
 	LogString encoding;
 	LOG4CXX_NS::helpers::CharsetEncoderPtr encoder;
@@ -109,7 +114,7 @@ void TelnetAppender::activateOptions(Pool& /* p */)
 {
 	if (_priv->serverSocket == NULL)
 	{
-		_priv->serverSocket = ServerSocket::create(_priv->port);
+		_priv->serverSocket = ServerSocket::create(_priv->port, _priv->reuseAddress, _priv->hostname);
 		_priv->serverSocket->setSoTimeout(1000);
 	}
 
@@ -132,6 +137,14 @@ void TelnetAppender::setOption(const LogString& option,
 	{
 		setEncoding(value);
 	}
+	else if (StringHelper::equalsIgnoreCase(option, LOG4CXX_STR("REUSEADDRESS"), LOG4CXX_STR("reuseaddress")))
+	{
+		setReuseAddress(OptionConverter::toBoolean(value, true));
+	}
+	else if (StringHelper::equalsIgnoreCase(option, LOG4CXX_STR("HOSTNAME"), LOG4CXX_STR("hostname")))
+	{
+		setHostname(value);
+	}
 	else
 	{
 		AppenderSkeleton::setOption(option, value);
@@ -333,6 +346,16 @@ void TelnetAppender::setPort(int port1)
 	_priv->port = port1;
 }
 
+LogString TelnetAppender::getHostname() const
+{
+	return _priv->hostname;
+}
+
+void TelnetAppender::setHostname(const LogString& hostname)
+{
+	_priv->hostname = hostname;
+}
+
 int TelnetAppender::getMaxConnections() const
 {
 	return static_cast<int>(_priv->connections.size());
@@ -355,6 +378,11 @@ void TelnetAppender::setMaxConnections(int newValue)
 	}
 }
 
+void TelnetAppender::setReuseAddress(bool reuseAddress)
+{
+	_priv->reuseAddress = reuseAddress;
+}
+
 bool TelnetAppender::requiresLayout() const
 {
 	return false;
