@@ -26,14 +26,32 @@
 #include <log4cxx/helpers/transform.h>
 #include <log4cxx/helpers/transcoder.h>
 #include <log4cxx/helpers/socketoutputstream.h>
+#include <log4cxx/private/appenderskeleton_priv.h>
+#include <log4cxx/private/socketappenderskeleton_priv.h>
 
-using namespace log4cxx;
-using namespace log4cxx::helpers;
-using namespace log4cxx::net;
-using namespace log4cxx::xml;
+using namespace LOG4CXX_NS;
+using namespace LOG4CXX_NS::helpers;
+using namespace LOG4CXX_NS::net;
+using namespace LOG4CXX_NS::xml;
+
+struct XMLSocketAppender::XMLSocketAppenderPriv : public SocketAppenderSkeletonPriv
+{
+	XMLSocketAppenderPriv(int defaultPort, int reconnectionDelay) :
+		SocketAppenderSkeletonPriv(defaultPort, reconnectionDelay) {}
+
+	XMLSocketAppenderPriv(InetAddressPtr address, int defaultPort, int reconnectionDelay) :
+		SocketAppenderSkeletonPriv( address, defaultPort, reconnectionDelay ) {}
+
+	XMLSocketAppenderPriv(const LogString& host, int port, int delay) :
+		SocketAppenderSkeletonPriv( host, port, delay ) {}
+
+	LOG4CXX_NS::helpers::WriterPtr writer;
+};
 
 IMPLEMENT_LOG4CXX_OBJECT(XMLSocketAppender)
 
+#define _priv static_cast<XMLSocketAppenderPriv*>(m_priv.get())
+
 // The default port number of remote logging server (4560)
 int XMLSocketAppender::DEFAULT_PORT                 = 4560;
 
@@ -43,23 +61,23 @@ int XMLSocketAppender::DEFAULT_RECONNECTION_DELAY   = 30000;
 const int XMLSocketAppender::MAX_EVENT_LEN          = 1024;
 
 XMLSocketAppender::XMLSocketAppender()
-	: SocketAppenderSkeleton(DEFAULT_PORT, DEFAULT_RECONNECTION_DELAY)
+	: SocketAppenderSkeleton(std::make_unique<XMLSocketAppenderPriv>(DEFAULT_PORT, DEFAULT_RECONNECTION_DELAY))
 {
-	layout = XMLLayoutPtr(new XMLLayout());
+	_priv->layout = std::make_shared<XMLLayout>();
 }
 
 XMLSocketAppender::XMLSocketAppender(InetAddressPtr address1, int port1)
-	: SocketAppenderSkeleton(address1, port1, DEFAULT_RECONNECTION_DELAY)
+	: SocketAppenderSkeleton(std::make_unique<XMLSocketAppenderPriv>(address1, port1, DEFAULT_RECONNECTION_DELAY))
 {
-	layout = XMLLayoutPtr(new XMLLayout());
+	_priv->layout = std::make_shared<XMLLayout>();
 	Pool p;
 	activateOptions(p);
 }
 
 XMLSocketAppender::XMLSocketAppender(const LogString& host, int port1)
-	: SocketAppenderSkeleton(host, port1, DEFAULT_RECONNECTION_DELAY)
+	: SocketAppenderSkeleton(std::make_unique<XMLSocketAppenderPriv>(host, port1, DEFAULT_RECONNECTION_DELAY))
 {
-	layout = XMLLayoutPtr(new XMLLayout());
+	_priv->layout = std::make_shared<XMLLayout>();
 	Pool p;
 	activateOptions(p);
 }
@@ -80,22 +98,22 @@ int XMLSocketAppender::getDefaultPort() const
 	return DEFAULT_PORT;
 }
 
-void XMLSocketAppender::setSocket(log4cxx::helpers::SocketPtr& socket, Pool& p)
+void XMLSocketAppender::setSocket(LOG4CXX_NS::helpers::SocketPtr& socket, Pool& p)
 {
-	OutputStreamPtr os(new SocketOutputStream(socket));
+	OutputStreamPtr os = std::make_shared<SocketOutputStream>(socket);
 	CharsetEncoderPtr charset(CharsetEncoder::getUTF8Encoder());
-	std::lock_guard<std::recursive_mutex> lock(mutex);
-	writer = OutputStreamWriterPtr(new OutputStreamWriter(os, charset));
+	std::lock_guard<std::recursive_mutex> lock(_priv->mutex);
+	_priv->writer = std::make_shared<OutputStreamWriter>(os, charset);
 }
 
 void XMLSocketAppender::cleanUp(Pool& p)
 {
-	if (writer != 0)
+	if (_priv->writer)
 	{
 		try
 		{
-			writer->close(p);
-			writer = 0;
+			_priv->writer->close(p);
+			_priv->writer = nullptr;
 		}
 		catch (std::exception&)
 		{
@@ -103,21 +121,21 @@ void XMLSocketAppender::cleanUp(Pool& p)
 	}
 }
 
-void XMLSocketAppender::append(const spi::LoggingEventPtr& event, log4cxx::helpers::Pool& p)
+void XMLSocketAppender::append(const spi::LoggingEventPtr& event, LOG4CXX_NS::helpers::Pool& p)
 {
-	if (writer != 0)
+	if (_priv->writer)
 	{
 		LogString output;
-		layout->format(output, event, p);
+		_priv->layout->format(output, event, p);
 
 		try
 		{
-			writer->write(output, p);
-			writer->flush(p);
+			_priv->writer->write(output, p);
+			_priv->writer->flush(p);
 		}
 		catch (std::exception& e)
 		{
-			writer = 0;
+			_priv->writer = nullptr;
 			LogLog::warn(LOG4CXX_STR("Detected problem with connection: "), e);
 
 			if (getReconnectionDelay() > 0)
