@@ -22,50 +22,74 @@
 	#error "aprinitializer.h should only be included by log4cxx implementation"
 #endif
 
-#include <list>
+#include <log4cxx/helpers/object.h>
+#include <log4cxx/helpers/widelife.h>
 
 extern "C" {
-	typedef struct apr_thread_mutex_t apr_thread_mutex_t;
-	typedef struct apr_threadkey_t apr_threadkey_t;
+	struct apr_threadkey_t;
+	struct apr_pool_t;
 }
+#include <functional>
 
-#include <apr_time.h>
-#include <mutex>
-
-namespace log4cxx
+namespace LOG4CXX_NS
 {
 namespace helpers
 {
+#if LOG4CXX_ABI_VERSION <= 15
 class FileWatchdog;
+#endif
 
 class APRInitializer
 {
 	public:
+#if LOG4CXX_ABI_VERSION <= 15
 		static log4cxx_time_t initialize();
-		static apr_pool_t* getRootPool();
-		static apr_threadkey_t* getTlsKey();
 		static bool isDestructed;
+#endif
+		static apr_pool_t* getRootPool();
+		static log4cxx_time_t getStartTime();
+		static apr_threadkey_t* getTlsKey();
 
+#if LOG4CXX_ABI_VERSION <= 15
 		/**
-		 *  Register a FileWatchdog for deletion prior to
-		 *    APR termination.  FileWatchdog must be
+		 *  Register a FileWatchdog for deletion prior to termination.
+		 *    FileWatchdog must be
 		 *    allocated on heap and not deleted elsewhere.
 		 */
 		static void registerCleanup(FileWatchdog* watchdog);
 		static void unregisterCleanup(FileWatchdog* watchdog);
+		static void unregisterAll();
+#endif
+		/**
+		 *  Store a single instance type ObjectPtr for deletion prior to termination
+		 */
+		template <class T> static void setUnique(const std::shared_ptr<T>& pObject)
+		{
+			getInstance().addObject(typeid(T).hash_code(), pObject);
+		}
+		/**
+		 *  Fetch or add a single instance type ObjectPtr for deletion prior to termination
+		 */
+		template <class T> static std::shared_ptr<T> getOrAddUnique(std::function<ObjectPtr()> creator)
+		{
+			return cast<T>(getInstance().findOrAddObject(typeid(T).hash_code(), creator));
+		}
 
-	private:
+
+	private: // Constructors
+		friend class helpers::WideLife<APRInitializer>;
 		APRInitializer();
-		APRInitializer(const APRInitializer&);
-		APRInitializer& operator=(const APRInitializer&);
-		apr_pool_t* p;
-		std::mutex mutex;
-		std::list<FileWatchdog*> watchdogs;
-		apr_time_t startTime;
-		apr_threadkey_t* tlsKey;
+		APRInitializer(const APRInitializer&) = delete;
+		APRInitializer& operator=(const APRInitializer&) = delete;
+	private: // Modifiers
+		void addObject(size_t key, const ObjectPtr& pObject);
+		const ObjectPtr& findOrAddObject(size_t key, std::function<ObjectPtr()> creator);
+	private: // Attributes
+		LOG4CXX_DECLARE_PRIVATE_MEMBER_PTR(APRInitializerPrivate, m_priv)
+	private: // Class methods
 		static APRInitializer& getInstance();
 
-	public:
+	public: // Destructor
 		~APRInitializer();
 };
 } // namespace helpers
