@@ -20,10 +20,9 @@
 
 #include <log4cxx/helpers/outputstream.h>
 #include <log4cxx/file.h>
-#include <log4cxx/helpers/pool.h>
 
 
-namespace log4cxx
+namespace LOG4CXX_NS
 {
 
 namespace helpers
@@ -55,10 +54,11 @@ class LOG4CXX_EXPORT FileOutputStream : public OutputStream
 		apr_file_t* getFilePtr() const;
 
 	private:
-		FileOutputStream(const FileOutputStream&);
-		FileOutputStream& operator=(const FileOutputStream&);
+		FileOutputStream(const FileOutputStream&) = delete;
+		FileOutputStream(FileOutputStream&&) = delete;
+		FileOutputStream& operator=(const FileOutputStream&) = delete;
 		static apr_file_t* open(const LogString& fn, bool append,
-			log4cxx::helpers::Pool& p);
+			LOG4CXX_NS::helpers::Pool& p);
 };
 
 LOG4CXX_PTR_DEF(FileOutputStream);
