@@ -18,13 +18,13 @@
 #ifndef _LOG4CXX_HELPERS_LOADER_H
 #define _LOG4CXX_HELPERS_LOADER_H
 
-#include <log4cxx/helpers/objectptr.h>
+#include <log4cxx/helpers/object.h>
 #include <log4cxx/logstring.h>
 #include <log4cxx/helpers/exception.h>
 #include <log4cxx/helpers/inputstream.h>
 
 
-namespace log4cxx
+namespace LOG4CXX_NS
 {
 namespace helpers
 {
