@@ -18,12 +18,6 @@
 #ifndef _LOG4CXX_STRING_H
 #define _LOG4CXX_STRING_H
 
-#if defined(_MSC_VER)
-	#pragma warning ( push )
-	#pragma warning ( disable: 4231 4251 4275 4786 )
-#endif
-
-
 #include <string>
 #include <log4cxx/log4cxx.h>
 
@@ -37,10 +31,10 @@ extern "C" {
 }
 #endif
 
-namespace log4cxx
+namespace LOG4CXX_NS
 {
 
-#if LOG4CXX_LOGCHAR_IS_UNICHAR || LOG4CXX_UNICHAR_API || LOG4CXX_CFSTRING_API
+#if LOG4CXX_LOGCHAR_IS_UNICHAR || LOG4CXX_UNICHAR_API
 	typedef unsigned short UniChar;
 #endif
 
@@ -52,7 +46,7 @@ namespace log4cxx
 #if LOG4CXX_LOGCHAR_IS_UTF8
 	typedef char logchar;
 	#if LOG4CXX_CHARSET_EBCDIC
-		#define LOG4CXX_STR(str) log4cxx::helpers::Transcoder::decode(str)
+		#define LOG4CXX_STR(str) LOG4CXX_NS::helpers::Transcoder::decode(str)
 	#else
 		#define LOG4CXX_STR(str) str
 	#endif
@@ -60,15 +54,13 @@ namespace log4cxx
 
 #if LOG4CXX_LOGCHAR_IS_UNICHAR
 	typedef UniChar logchar;
-	#define LOG4CXX_STR(str) log4cxx::helpers::Transcoder::decode(str)
+	#define LOG4CXX_STR(str) LOG4CXX_NS::helpers::Transcoder::decode(str)
 #endif
 
 typedef std::basic_string<logchar> LogString;
 
-
 }
 
-
 #if !defined(LOG4CXX_EOL)
 	#if defined(_WIN32)
 		#define LOG4CXX_EOL LOG4CXX_STR("\x0D\x0A")
@@ -82,8 +74,4 @@ typedef std::basic_string<logchar> LogString;
 	#include <log4cxx/helpers/transcoder.h>
 #endif
 
-#if defined(_MSC_VER)
-	#pragma warning (pop)
-#endif
-
 #endif //_LOG4CXX_STRING_H
