@@ -22,7 +22,7 @@
 #include <log4cxx/helpers/object.h>
 #include <log4cxx/logstring.h>
 
-namespace log4cxx
+namespace LOG4CXX_NS
 {
 namespace pattern
 {
@@ -40,23 +40,9 @@ typedef std::shared_ptr<FormattingInfo> FormattingInfoPtr;
  *
  *
  */
-class LOG4CXX_EXPORT FormattingInfo : public virtual log4cxx::helpers::Object
+class LOG4CXX_EXPORT FormattingInfo : public virtual LOG4CXX_NS::helpers::Object
 {
-
-		/**
-		 * Minimum length.
-		 */
-		const int minLength;
-
-		/**
-		 * Maximum length.
-		 */
-		const int maxLength;
-
-		/**
-		 * Alignment.
-		 */
-		const bool leftAlign;
+		LOG4CXX_DECLARE_PRIVATE_MEMBER_PTR(FormattingInfoPrivate, m_priv)
 
 	public:
 		DECLARE_ABSTRACT_LOG4CXX_OBJECT(FormattingInfo)
@@ -73,6 +59,7 @@ class LOG4CXX_EXPORT FormattingInfo : public virtual log4cxx::helpers::Object
 		 */
 		FormattingInfo(
 			const bool leftAlign, const int minLength, const int maxLength);
+		~FormattingInfo();
 
 		/**
 		 * Gets default instance.
@@ -84,28 +71,19 @@ class LOG4CXX_EXPORT FormattingInfo : public virtual log4cxx::helpers::Object
 		 * Determine if left aligned.
 		 * @return true if left aligned.
 		 */
-		inline bool isLeftAligned() const
-		{
-			return leftAlign;
-		}
+		bool isLeftAligned() const;
 
 		/**
 		 * Get minimum length.
 		 * @return minimum length.
 		 */
-		inline int getMinLength() const
-		{
-			return minLength;
-		}
+		int getMinLength() const;
 
 		/**
 		 * Get maximum length.
 		 * @return maximum length.
 		 */
-		inline int getMaxLength() const
-		{
-			return maxLength;
-		}
+		int getMaxLength() const;
 
 		/**
 		 * Adjust the content of the buffer based on the specified lengths and alignment.
