@@ -20,7 +20,7 @@
 
 #include <locale>
 
-namespace log4cxx
+namespace LOG4CXX_NS
 {
 namespace helpers
 {
