@@ -20,12 +20,12 @@
 #include "../appenderskeletontestcase.h"
 #include <apr_thread_proc.h>
 #include <apr_time.h>
+#include <thread>
 
 using namespace log4cxx;
 using namespace log4cxx::helpers;
 using namespace log4cxx::net;
 
-#if APR_HAS_THREADS
 /**
    Unit tests of log4cxx::TelnetAppender
  */
@@ -40,6 +40,7 @@ class TelnetAppenderTestCase : public AppenderSkeletonTestCase
 		LOGUNIT_TEST(testActivateClose);
 		LOGUNIT_TEST(testActivateSleepClose);
 		LOGUNIT_TEST(testActivateWriteClose);
+		LOGUNIT_TEST(testActivateWriteNoClose);
 
 		LOGUNIT_TEST_SUITE_END();
 
@@ -76,7 +77,7 @@ class TelnetAppenderTestCase : public AppenderSkeletonTestCase
 			appender->setPort(TEST_PORT);
 			Pool p;
 			appender->activateOptions(p);
-			std::this_thread::sleep_for( std::chrono::milliseconds( 1000 ) );
+			std::this_thread::sleep_for( std::chrono::milliseconds( 100 ) );
 			appender->close();
 		}
 
@@ -96,9 +97,31 @@ class TelnetAppenderTestCase : public AppenderSkeletonTestCase
 			}
 
 			appender->close();
+			root->removeAppender(appender);
+		}
+
+		void testActivateWriteNoClose()
+		{
+			TelnetAppenderPtr appender(new TelnetAppender());
+			appender->setPort(TEST_PORT);
+			appender->setMaxConnections(1);
+			appender->setReuseAddress(true);
+			appender->setHostname(LOG4CXX_STR("127.0.0.1"));
+			Pool p;
+			appender->activateOptions(p);
+			LoggerPtr root(Logger::getRootLogger());
+			root->addAppender(appender);
+
+			for (int i = 0; i < 50; i++)
+			{
+//#define ALLOW_TESTING_WITH_TELNET
+#ifdef ALLOW_TESTING_WITH_TELNET
+				std::this_thread::sleep_for( std::chrono::milliseconds( 1000 ) );
+#endif
+				LOG4CXX_INFO(root, "Hello, World " << i);
+			}
 		}
 
 };
 
 LOGUNIT_TEST_SUITE_REGISTRATION(TelnetAppenderTestCase);
-#endif
