@@ -80,6 +80,7 @@ LOGUNIT_CLASS(PatternParserTestCase)
 	LOGUNIT_TEST(testBasic2);
 	LOGUNIT_TEST(testMultiOption);
 	LOGUNIT_TEST(testThreadUsername);
+	LOGUNIT_TEST(testInvalidPatterns);
 	LOGUNIT_TEST_SUITE_END();
 
 	LoggingEventPtr event;
@@ -270,6 +271,13 @@ public:
 		assertFormattedEquals(LOG4CXX_STR("%d{HH:mm:ss}{GMT} %d{HH:mm:ss} %c  - %m"),
 			getFormatSpecifiers(),
 			expected);
+		// Check an invalid timezone is equivalent to an unspecified timezone
+		assertFormattedEquals(LOG4CXX_STR("%d{HH:mm:ss}{GMT} %d{HH:mm:ss}{GMT-X} %c  - %m"),
+			getFormatSpecifiers(),
+			expected);
+		assertFormattedEquals(LOG4CXX_STR("%d{HH:mm:ss}{GMT} %d{HH:mm:ss}{GMT-1:62222222} %c  - %m"),
+			getFormatSpecifiers(),
+			expected);
 	}
 
 	void testThreadUsername()
@@ -289,6 +297,16 @@ public:
 			expected);
 	}
 
+	void testInvalidPatterns()
+	{
+		assertFormattedEquals(LOG4CXX_STR("%6666c"),
+			getFormatSpecifiers(),
+			LOG4CXX_STR("%6666c"));
+		assertFormattedEquals(LOG4CXX_STR("%6.6666c"),
+			getFormatSpecifiers(),
+			LOG4CXX_STR("%6.6666c"));
+	}
+
 };
 
 //
