@@ -95,8 +95,12 @@ public:
 	void tearDown()
 	{
 		MDC::clear();
-		if (auto rep = root->getLoggerRepository())
+		auto rep = root->getLoggerRepository();
+
+		if (rep)
+		{
 			rep->resetConfiguration();
+		}
 	}
 
 	void test1()
