@@ -21,7 +21,7 @@
 #include "filter.h"
 #include <vector>
 
-namespace log4cxx
+namespace LOG4CXX_NS
 {
 class ControlFilter : public Filter
 {
