@@ -53,6 +53,9 @@ LOGUNIT_CLASS(DOMTestCase)
 #endif
 	LOGUNIT_TEST(test3);
 	LOGUNIT_TEST(test4);
+	LOGUNIT_TEST(recursiveAppenderRef);
+	LOGUNIT_TEST(invalidAppender);
+	LOGUNIT_TEST(invalidLevel);
 	LOGUNIT_TEST_SUITE_END();
 
 	LoggerPtr root;
@@ -76,7 +79,9 @@ public:
 
 	void tearDown()
 	{
-		if (auto rep = root->getLoggerRepository())
+		auto rep = root->getLoggerRepository();
+
+		if (rep)
 		{
 			rep->resetConfiguration();
 		}
@@ -224,6 +229,27 @@ public:
 		bool exists = file.exists(p);
 		LOGUNIT_ASSERT(exists);
 	}
+
+
+	void recursiveAppenderRef()
+	{
+		// Load a bad XML file, make sure that we don't crash in endless recursion
+		DOMConfigurator::configure(LOG4CXX_TEST_STR("input/xml/DOMConfiguratorRecursive.xml"));
+  }
+
+	void invalidAppender()
+	{
+		// Load an XML file that attempts to use a levelmatchfilter as an appender.
+		// We should not crash when loading this file.
+		DOMConfigurator::configure(LOG4CXX_TEST_STR("input/xml/DOMInvalidAppender.xml"));
+  }
+  
+	void invalidLevel()
+	{
+		// Load an XML file that attempts to use a filter as a level.
+		// We should not crash when loading this file.
+		DOMConfigurator::configure(LOG4CXX_TEST_STR("input/xml/DOMInvalidLevel.xml"));
+	}
 };
 
 LOGUNIT_TEST_SUITE_REGISTRATION(DOMTestCase);
